<template>
  <div class="layout-padding layout-padding-unset layout-iframe">
    <div class="layout-padding-auto layout-padding-view">
      <div class="w100" v-for="v in setIframeList" :key="v.path" v-loading="v.meta.loading"
        element-loading-background="#ccc">
        <transition-group :name="name" mode="out-in">
          <iframe :src="v.meta.isLink" :key="v.path" frameborder="0" height="100%" width="100%" style="position: absolute"
            :data-url="v.path" v-show="getRoutePath === v.path" ref="iframeRef" />
        </transition-group>
      </div>
    </div>
  </div>
</template>

<script setup lang="ts" name="layoutIfameView">
import { ref, computed, watch, nextTick } from 'vue'
import { useRoute } from 'vue-router'
const props = defineProps({
  refreshKey: {
    type: String,
    default: () => ''
  },
  name: {
    type: String,
    default: () => 'slide-right'
  },
  list: {//返回路由所有iframe的数组
    type: Array,
    default: () => []
  }
})
const iframeRef = ref()
const route = useRoute()
console.log('iframe-route', route.fullPath)
// 处理 list 列表，当打开时，才进行加载
const setIframeList = computed(() => {//返回路由所有iframe的数组
  return (<any>props.list).filter((v: any) => v.meta.isIframeOpen)
})
// 获取 iframe 当前路由 path
const getRoutePath = computed(() => {
  return route.path
})
// 关闭 iframe loading
const closeIframeLoading = (val: string, item: any) => {
  nextTick(() => {
    console.log('iframeRef', iframeRef.value)//返回所有iframe的数组
    if (!iframeRef.value) return false
    iframeRef.value.forEach((v: any) => {
      if (v.dataset.url === val) {
        v.onload = () => {
          if (item.meta.isIframeOpen && item.meta.loading) item.meta.loading = false
        }
      }
    })
  })
}
// 监听路由变化，初始化 iframe 数据，防止多个 iframe 时，切换不生效
watch(() => route.fullPath, (val) => {
  const item: any = props.list.find((v: any) => v.path === val)//find返回值：	返回符合测试条件的'第一个数组元素值'，如果没有符合条件的则返回 undefined。
  console.log('88', item)
  console.log(item)
  if (!item) return false
  if (!item.meta.isIframeOpen) item.meta.isIframeOpen = true //先关闭，在打开iframe
  closeIframeLoading(val, item)
}, { immediate: true })

// 监听 iframe refreshKey 变化，用于 tagsview 右键菜单刷新
watch(() => props.refreshKey, () => {
  const item: any = props.list.find((v: any) => v.path === route.path)
  if (!item) return false
  if (item.meta.isIframeOpen) item.meta.isIframeOpen = false
  setTimeout(() => {
    item.meta.isIframeOpen = true
    item.meta.loading = true
    closeIframeLoading(route.fullPath, item)
  });
}, { deep: true })
</script>
<style lang='scss' scoped></style>